@@ -220,6 +220,8 @@ bool KTextToHTMLHelper::atUrl() const
         || segment.startsWith(QLatin1String("ftps://"))
         || segment.startsWith(QLatin1String("sftp://"))
         || segment.startsWith(QLatin1String("smb://"))
+        || segment.startsWith(QLatin1String("irc://"))
+        || segment.startsWith(QLatin1String("ircs://"))
         || segment.startsWith(QLatin1String("mailto:"))
         || segment.startsWith(QLatin1String("www."))
         || segment.startsWith(QLatin1String("ftp."))
@@ -242,6 +244,8 @@ bool KTextToHTMLHelper::isEmptyUrl(const QString &url) const
         || url == QLatin1String("sftp://")
         || url == QLatin1String("smb://")
         || url == QLatin1String("vnc://")
+        || url == QLatin1String("irc://")
+        || url == QLatin1String("ircs://")
         || url == QLatin1String("mailto")
         || url == QLatin1String("mailto:")
         || url == QLatin1String("www")
@@ -269,7 +273,8 @@ QString KTextToHTMLHelper::getUrl(bool *badurl)
         // Also, if the URL is enclosed in brackets, the URL itself is not allowed
         // to contain the closing bracket, as this would be detected as the end of the URL
 
-        QChar beforeUrl, afterUrl;
+        QChar beforeUrl;
+        QChar afterUrl;
 
         // detect if the url has been surrounded by brackets or quotes
         if (mPos > 0) {
